@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -32,6 +28,7 @@ short_description = _('Computer: Linux')
 object_name = _('Linux Computer')
 object_name_plural = _('Linux Computers')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -247,6 +244,7 @@ mapping.register('operatingSystem', 'univentionOperatingSystem', None, univentio
 mapping.register('operatingSystemVersion', 'univentionOperatingSystemVersion', None, univention.admin.mapping.ListToString)
 register_pki_mapping(mapping)
 register_role_mapping(mapping)
+# fmt: on
 
 # add Nagios extension
 nagios.addPropertiesMappingOptionsAndLayout(property_descriptions, mapping, options, layout)
@@ -275,7 +273,7 @@ class object(ComputerObject):
                     univention.admin.filter.expression('objectClass', 'krb5Principal'),
                 ]),
             ]),
-        )
+        )  # fmt: skip
         return con
 
 
@@ -284,4 +282,8 @@ lookup_filter = object.lookup_filter
 
 
 def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> bool:
-    return b'univentionHost' in attr.get('objectClass', []) and b'univentionLinuxClient' in attr.get('objectClass', []) and (b'posixAccount' in attr.get('objectClass', []) or (b'krb5KDCEntry' in attr.get('objectClass', []) and b'krb5Principal' in attr.get('objectClass', [])))
+    return (
+        b'univentionHost' in attr.get('objectClass', [])
+        and b'univentionLinuxClient' in attr.get('objectClass', [])
+        and (b'posixAccount' in attr.get('objectClass', []) or (b'krb5KDCEntry' in attr.get('objectClass', []) and b'krb5Principal' in attr.get('objectClass', [])))
+    )
