@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -28,6 +24,7 @@ Range = tuple[IPv4Address, IPv4Address]
 translation = univention.admin.localization.translation('univention.admin.handlers.dhcp')
 _ = translation.translate
 
+# fmt: off
 _properties = {
     'option': univention.admin.property(
         short_description=_('DHCP options'),
@@ -47,7 +44,7 @@ _properties = {
 _options = {
     'options': univention.admin.option(
         short_description=_('Allow custom DHCP options'),
-        long_description=_("Allow adding custom DHCP options. Experts only!"),
+        long_description=_('Allow adding custom DHCP options. Experts only!'),
         default=False,
         editable=True,
         objectClasses=['dhcpOptions'],
@@ -57,6 +54,7 @@ _mappings = (
     ('option', 'dhcpOption', None, None, 'ASCII'),
     ('statements', 'dhcpStatements', None, None, 'ASCII'),
 )
+# fmt: on
 
 
 def rangeMap(value: Iterable[list[str]], encoding: tuple[str, ...] = ()) -> list[bytes]:
@@ -86,7 +84,7 @@ def add_dhcp_options(module_name: str) -> None:
         _('Custom DHCP options'),
         advanced=True,
         layout=['option', 'statements'],
-    ))
+    ))  # fmt: skip
 
 
 def check_range_overlap(ranges: Sequence[Range]) -> None:
