@@ -436,13 +436,13 @@ class TimeType(StringType):
 class DateTimeType(StringType):
     """
     A DateTime
-            syntax classes using this type must support the method from_datetime(), which returns something valid for syntax.parse()
+        syntax classes using this type must support the method from_datetime(), which returns something valid for syntax.parse()
 
     >>> x = DateTimeType(univention.admin.property(syntax=univention.admin.syntax.string), 'a_date_time')
     >>> import datetime
     >>> now = datetime.datetime(2020, 1, 1)
     >>> x.to_json_type(now)  # doctest: +ALLOW_UNICODE
-    '2020-01-01 00:00:00'
+    '2020-01-01T00:00:00'
     """
 
     _python_types = datetime.datetime
@@ -458,7 +458,7 @@ class DateTimeType(StringType):
         return self.syntax.from_datetime(value)
 
     def _to_json_type(self, value: datetime.datetime) -> str:
-        return ' '.join((value.date().isoformat(), value.time().replace(microsecond=0).isoformat()))
+        return value.replace(microsecond=0).isoformat()
 
     def _from_json_type(self, value: str) -> datetime.datetime:
         try:
